// IndexedDB Ayarları
const db = new Dexie("StudentLessonDatabase");
db.version(1).stores({
    students: "++id, name" // Öğrenci tablosu
});

// Elle Öğrenci Ekleme
document.getElementById("addStudentButton").addEventListener("click", async () => {
    const name = document.getElementById("studentName").value.trim();
    const message = document.getElementById("manualMessage");

    if (name) {
        try {
            const existingStudent = await db.students.where("name").equalsIgnoreCase(name).first();
            if (existingStudent) {
                message.innerText = "Bu öğrenci zaten eklenmiş.";
            } else {
                await db.students.add({ name });
                message.innerText = "Öğrenci başarıyla eklendi.";
                document.getElementById("studentName").value = ""; // Alanı temizle
            }
        } catch (error) {
            console.error("Elle ekleme sırasında bir hata oluştu:", error);
            message.innerText = "Bir hata oluştu. Lütfen tekrar deneyin.";
        }
    } else {
        message.innerText = "Lütfen bir ad soyad girin.";
    }
});

// Dosya ile Öğrenci Ekleme
document.getElementById("uploadButton").addEventListener("click", () => {
    const file = document.getElementById("uploadExcel").files[0];
    const message = document.getElementById("excelMessage");

    if (!file) {
        message.innerText = "Lütfen bir dosya seçin.";
        return;
    }

    const allowedExtensions = [".xls", ".xlsx", ".txt"];
    const fileExtension = file.name.substring(file.name.lastIndexOf(".")).toLowerCase();

    if (!allowedExtensions.includes(fileExtension)) {
        message.innerText = "Desteklenmeyen dosya türü. Lütfen uygun bir dosya seçin.";
        return;
    }

    const reader = new FileReader();

    if (fileExtension === ".xls" || fileExtension === ".xlsx") {
        reader.onload = async (e) => {
            try {
                const data = new Uint8Array(e.target.result);
                const workbook = XLSX.read(data, { type: "array" });
                const sheet = workbook.Sheets[workbook.SheetNames[0]];
                const rows = XLSX.utils.sheet_to_json(sheet, { header: 1 });

                console.log("Excel Satırları:", rows);
                await processRows(rows);
                message.innerText = "Excel dosyasından öğrenciler başarıyla eklendi.";
            } catch (error) {
                console.error("Excel dosyası işlenirken bir hata oluştu:", error);
                message.innerText = "Excel dosyası işlenirken bir hata oluştu.";
            }
        };
        reader.readAsArrayBuffer(file);
    } else if (fileExtension === ".txt") {
        reader.onload = async (e) => {
            try {
                const content = e.target.result;
                const rows = content.split("\n").map(row => row.trim()).filter(row => row);
                console.log("TXT Satırları:", rows);
                await processRows(rows.map(row => [row])); // TXT için satırları tek hücrelik bir array yap
                message.innerText = "TXT dosyasından öğrenciler başarıyla eklendi.";
            } catch (error) {
                console.error("TXT dosyası işlenirken bir hata oluştu:", error);
                message.innerText = "TXT dosyası işlenirken bir hata oluştu.";
            }
        };
        reader.readAsText(file);
    }
});

// Satırları İşleme Fonksiyonu
async function processRows(rows) {
    const message = document.getElementById("excelMessage");
    let addedCount = 0;

    for (const row of rows) {
        const name = row.filter(cell => cell).join(" ").trim(); // Satırdaki hücreleri birleştir
        if (name) {
            try {
                const existingStudent = await db.students.where("name").equalsIgnoreCase(name).first();
                if (!existingStudent) {
                    await db.students.add({ name });
                    addedCount++;
                }
            } catch (error) {
                console.error("Öğrenci eklenirken bir hata oluştu:", error);
            }
        }
    }

    message.innerText = `${addedCount} öğrenci başarıyla eklendi.`;
}

// Ana Sayfaya Dön
document.getElementById("backButton").addEventListener("click", () => {
    window.location.href = "../index.html";
});
