// IndexedDB Ayarları
const db = new Dexie("StudentLessonDatabase");
db.version(1).stores({
    students: "++id, name"
});

// Öğrenci Listesini Yükle
async function loadStudents() {
    const studentList = document.getElementById("studentList");
    studentList.innerHTML = ""; // Mevcut listeyi temizle

    const students = await db.students.toArray();
    students.forEach(student => {
        const listItem = document.createElement("li");

        // Checkbox
        const checkbox = document.createElement("input");
        checkbox.type = "checkbox";
        checkbox.value = student.id;

        // Öğrenci Adı
        const studentName = document.createElement("span");
        studentName.textContent = student.name;

        listItem.appendChild(checkbox);
        listItem.appendChild(studentName);
        studentList.appendChild(listItem);
    });
}

// Tüm Öğrencileri Sil
document.getElementById("deleteAllButton").addEventListener("click", async () => {
    const confirmation = confirm("Tüm öğrencileri silmek istediğinize emin misiniz?");
    if (confirmation) {
        await db.students.clear();
        loadStudents();
        alert("Tüm öğrenciler silindi.");
    }
});

// Seçilen Öğrencileri Sil
document.getElementById("deleteSelectedButton").addEventListener("click", async () => {
    const selectedCheckboxes = document.querySelectorAll("#studentList input[type='checkbox']:checked");
    const idsToDelete = Array.from(selectedCheckboxes).map(checkbox => parseInt(checkbox.value));

    if (idsToDelete.length > 0) {
        const confirmation = confirm(`${idsToDelete.length} öğrenciyi silmek istediğinize emin misiniz?`);
        if (confirmation) {
            await db.students.bulkDelete(idsToDelete);
            loadStudents();
            alert(`${idsToDelete.length} öğrenci silindi.`);
        }
    } else {
        alert("Lütfen silmek istediğiniz öğrencileri seçin.");
    }
});

// Ana Sayfaya Dön
document.getElementById("backButton").addEventListener("click", () => {
    window.location.href = "../index.html";
});

// Sayfa yüklendiğinde öğrencileri listele
loadStudents();
