// IndexedDB Ayarları
const db = new Dexie("StudentLessonDatabase");
db.version(1).stores({
    lessons: "++id, name, isDefault" // Ders tablosu
});


// Varsayılan dersleri ekleme fonksiyonu
async function addDefaultLessons() {
    const defaultLessons = [
        { name: "Türkçe", isDefault: true },
        { name: "Matematik", isDefault: true },
        { name: "Hayat Bilgisi", isDefault: true }
    ];

    for (const lesson of defaultLessons) {
        const existingLesson = await db.lessons.where("name").equalsIgnoreCase(lesson.name).first();
        if (!existingLesson) {
            await db.lessons.add(lesson);
        }
    }
}

// Sayfa yüklendiğinde varsayılan dersleri ekle
//addDefaultLessons();

// Mevcut dersleri yükle
async function loadLessons() {
    const lessonList = document.getElementById("lessonList");
    lessonList.innerHTML = ""; // Listeyi temizle
    const lessons = await db.lessons.toArray();

    lessons.forEach(lesson => {
        const li = document.createElement("li");
        li.textContent = lesson.name;

        // Silme butonu ekle
        const deleteButton = document.createElement("button");
        deleteButton.textContent = "Sil";
        deleteButton.className = "delete-button";
        deleteButton.addEventListener("click", async () => {
            if (confirm(`${lesson.name} dersini silmek istediğinize emin misiniz?`)) {
                await db.lessons.delete(lesson.id);
                loadLessons(); // Listeyi güncelle
            }
        });

        li.appendChild(deleteButton);
        lessonList.appendChild(li);
    });
}



// Yeni ders ekleme işlemi
document.getElementById("addLessonButton").addEventListener("click", async () => {
    const newLessonInput = document.getElementById("newLessonInput");
    const lessonMessage = document.getElementById("lessonMessage");

    const newLessonName = newLessonInput.value.trim();
    if (!newLessonName) {
        lessonMessage.textContent = "Lütfen bir ders adı girin.";
        return;
    }

    // Aynı isimde ders olup olmadığını kontrol et
    const existingLesson = await db.lessons.where("name").equalsIgnoreCase(newLessonName).first();
    if (existingLesson) {
        lessonMessage.textContent = "Bu ders zaten mevcut.";
    } else {
        await db.lessons.add({ name: newLessonName, isDefault: false });
        lessonMessage.textContent = "Yeni ders başarıyla eklendi.";
        newLessonInput.value = ""; // Input'u temizle
        loadLessons(); // Listeyi güncelle
    }
});

// Ana sayfaya dön
document.getElementById("backButton").addEventListener("click", () => {
    window.location.href = "../index.html";
});

// Sayfa yüklendiğinde dersleri yükle
loadLessons();
