// IndexedDB Ayarları
const db = new Dexie("StudentLessonDatabase");
db.version(2).stores({
    students: "++id, name",
    lessons: "++id, name, isDefault",
    settings: "key, value",
    lessonSelections: "++id, lesson, studentId"
});



let currentLesson = "Türkçe"; // Varsayılan ders

// Ders değiştirme (sidebar'dan tıklanarak ders değiştirilir)
document.querySelectorAll(".lesson-button").forEach(button => {
    button.addEventListener("click", () => {
        currentLesson = button.textContent; // Buton üzerindeki metni al
        updateCurrentLesson(); // Ders adı güncellenir
        document.getElementById("selectedStudentDisplay").innerText = "Henüz öğrenci seçilmedi"; // Seçilen öğrenci sıfırlanır
        displayStudents(); // Listeleri güncelle
    });
});

// Ders Adını Güncelleme Fonksiyonu
function updateCurrentLesson() {
    const lessonDisplay = document.getElementById("currentLessonDisplay");
    lessonDisplay.textContent = currentLesson; // Seçili ders adını günceller
    document.getElementById("selectedStudentDisplay").innerText = "Henüz öğrenci seçilmedi";
}

// Öğrenci seçme
document.getElementById("selectStudentButton").addEventListener("click", async () => {
    const students = await db.students.toArray();
    const lessonSelections = await db.lessonSelections.where({ lesson: currentLesson }).toArray();
    const selectedIds = lessonSelections.map(s => s.studentId);

    const remainingStudents = students.filter(student => !selectedIds.includes(student.id));

    if (remainingStudents.length > 0) {
        const randomIndex = Math.floor(Math.random() * remainingStudents.length);
        const selectedStudent = remainingStudents[randomIndex];
        await db.lessonSelections.add({ lesson: currentLesson, studentId: selectedStudent.id });
        document.getElementById("selectedStudentDisplay").innerText = selectedStudent.name;
        displayStudents();
    } else {
        await resetSelectionsForCurrentLesson();
        document.getElementById("selectedStudentDisplay").innerText = "Tüm öğrenciler seçildi ve liste yenilendi!";
    }
});

// Öğrencileri listele
async function displayStudents() {
    const students = await db.students.toArray();
    const lessonSelections = await db.lessonSelections.where({ lesson: currentLesson }).toArray();
    const selectedIds = lessonSelections.map(s => s.studentId);

    const remainingStudents = students.filter(student => !selectedIds.includes(student.id));
    document.getElementById("remainingStudents").innerHTML = remainingStudents.map(student => `<li>${student.name}</li>`).join("");

    const selectedStudents = students.filter(student => selectedIds.includes(student.id));
    document.getElementById("selectedStudents").innerHTML = selectedStudents.map(student => `<li>${student.name}</li>`).join("");
}

// Listeyi sıfırlama (tüm seçimleri temizleme)
async function resetSelectionsForCurrentLesson() {
    await db.lessonSelections.where({ lesson: currentLesson }).delete();
    displayStudents();
}

// "Öğrenci Ekle" butonuna tıklama
document.getElementById("addStudentButton").addEventListener("click", () => {
    window.location.href = "dosyalar/add-student.html"; // Öğrenci ekleme sayfasına yönlendirme
});

// "Öğrenci Sil" butonuna tıklama
document.getElementById("deleteStudentButton").addEventListener("click", () => {
    window.location.href = "dosyalar/delete-student.html"; // Öğrenci silme sayfasına yönlendirme
});

// "Dersleri Düzenle" butonuna tıklama
document.getElementById("editLessonsButton").addEventListener("click", () => {
    window.location.href = "dosyalar/edit-lessons.html"; // Ders düzenleme sayfasına yönlendirme
});


// Varsayılan dersleri yükle (sadece bir kez)
async function addDefaultLessons() {
    // settings tablosunu kontrol et
    const setupCompleted = await db.settings.get("setupCompleted");
    if (!setupCompleted) {
        const defaultLessons = [
            { name: "Türkçe", isDefault: true },
            { name: "Matematik", isDefault: true },
            { name: "Hayat Bilgisi", isDefault: true }
        ];

        // Varsayılan dersleri ekle
        for (const lesson of defaultLessons) {
            const existingLesson = await db.lessons.where("name").equalsIgnoreCase(lesson.name).first();
            if (!existingLesson) {
                await db.lessons.add(lesson);
            }
        }

        // setupCompleted işaretini ekle
        await db.settings.put({ key: "setupCompleted", value: true });
    }
}


// Mevcut Dersleri Sidebar'a Yükleme
async function loadLessons() {
    const sidebar = document.querySelector(".sidebar");
    sidebar.innerHTML = ""; // Eski dersleri temizle
    const lessons = await db.lessons.toArray();

    lessons.forEach(lesson => {
        const button = document.createElement("button");
        button.className = "lesson-button";
        button.textContent = lesson.name;
        button.dataset.lesson = lesson.name;

        button.addEventListener("click", () => {
            currentLesson = lesson.name;
            updateCurrentLesson();
            displayStudents();
        });

        sidebar.appendChild(button);
    });

    // "Dersleri Düzenle" butonunu sidebar'a ekle
    const editButton = document.createElement("button");
    editButton.id = "editLessonsButton";
    editButton.textContent = "Ders Ekle - Sil";
    editButton.addEventListener("click", () => {
        window.location.href = "dosyalar/edit-lessons.html";
    });

    sidebar.appendChild(editButton);
}

// Ders ekleme butonunu sidebar'a ekleme
function addLessonButtonToSidebar(lessonName) {
    const sidebar = document.querySelector(".sidebar");
    const button = document.createElement("button");
    button.className = "lesson-button";
    button.textContent = lessonName;
    button.dataset.lesson = lessonName;
    button.addEventListener("click", () => {
        currentLesson = lessonName;
        updateCurrentLesson();
        displayStudents();
    });
    sidebar.insertBefore(button, document.getElementById("editLessonsButton")); // "Dersleri Düzenle" butonundan önce ekle
}


// Sayfa yüklendiğinde çalıştır
(async () => {
    await addDefaultLessons(); // Varsayılan dersleri yükle
    loadLessons(); // Dersleri yükle
    updateCurrentLesson();
    displayStudents();
})();